@@ -110,13 +110,10 @@ struct ImageCacheStatistics {
 
 struct UdimInfo {
     ustring filename;
-    ImageCacheFile* icfile = nullptr;
+    std::atomic<ImageCacheFile*> icfile { nullptr };
     int u, v;
 
-    UdimInfo()
-        : icfile(nullptr)
-    {
-    }
+    UdimInfo() {}
     UdimInfo(ustring filename, ImageCacheFile* icfile, int u, int v)
         : filename(filename)
         , icfile(icfile)
@@ -124,6 +121,21 @@ struct UdimInfo {
         , v(v)
     {
     }
+    UdimInfo(const UdimInfo& other)
+        : filename(other.filename)
+        , icfile(other.icfile.load())
+        , u(other.u)
+        , v(other.v)
+    {
+    }
+    const UdimInfo& operator=(const UdimInfo& other)
+    {
+        filename = other.filename;
+        icfile   = other.icfile.load();
+        u        = other.u;
+        v        = other.v;
+        return *this;
+    }
 };
 
 
